<?php
/**
 * The Customizer.
 *
 * @package Collect
 * @since Collect 1.0
 *
 * Namespace prefix abc_ = Alphabet Themes
 * All functions in this file are part of the Alphabet Themes framework.
 */

function collect_default_theme_options() {
	//delete_option( 'theme_mods_collect' );
	return array(
		'read_more_text' => 'Read more >',
		'display_author_id' => '0',
	);
}

class Collect_Customizer {
	public function __construct() {
		add_action( 'init', array( $this, 'init' ) );
		add_action( 'customize_register', array( $this, 'customize_register' ), 99 );
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'customize_controls_enqueue_scripts' ) );
		add_action( 'customize_preview_init', array( $this, 'customize_preview_init' ) );
	}

	static public function init() {
    	if ( current_user_can( 'edit_theme_options' ) ) {
	        if ( isset( $_REQUEST['abc-reset'] ) ) {
		    	if ( ! wp_verify_nonce( $_REQUEST['abc-reset'], 'abc-customizer' ) ) {
		        	return;
		        }

				remove_theme_mods();
				wp_redirect( esc_url( admin_url( 'customize.php' ) ) );
            }
    	}
    }

	public function customize_register( $wp_customize ) {
		$collect_default_theme_options = collect_default_theme_options();

		/**
		 * Custom controls
		 */
		require_once dirname( __FILE__ ) . '/class-abc-customizer-controls.php';

		if ( ! function_exists( 'abc_premium_features' ) ) {
			require_once dirname( __FILE__ ) . '/class-abc-customizer-sections.php';
		}

		$wp_customize->get_control( 'background_color' )->label = __( 'Sidebar Color', 'collect' );
		$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
		$wp_customize->get_setting( 'background_color' )->transport = 'postMessage';
		$wp_customize->remove_section( 'background_image' );

		## Posts section
		$wp_customize->add_section( 'abc_layout', array(
			'title' => __( 'Layout', 'collect' ),
			'priority' => 22,
		) );
		// setting
		$wp_customize->add_setting( 'read_more_text', array(
			'default' => $collect_default_theme_options['read_more_text'],
			'transport' => 'postMessage',
			'sanitize_callback' => 'collect_sanitize_text',
		) );
		// control
		$wp_customize->add_control( 'read_more_text', array(
			'label'    => __( 'Read More text', 'collect' ),
			'section'  => 'abc_layout',
			'priority' => 1,
			'type'     => 'text'
		) );
		// setting
		$wp_customize->add_setting( 'display_author_id', array(
			'default' => $collect_default_theme_options['display_author_id'],
			'sanitize_callback' => 'absint',
		) );
		// control
		$wp_customize->add_control( 'display_author_id', array(
			'label' => __( 'Select Author', 'collect' ),
			'section' => 'abc_layout',
			'priority' => 2,
			'description' => __( 'Add an author ID to display their avatar and info in the sidebar.', 'collect' ),
			'type' => 'text',
		) );

		## Reset section
		$wp_customize->add_section( 'abc_reset', array(
			'title' => __( 'Reset', 'collect' ),
			'priority' => 999,
		) );
		// setting
		$wp_customize->add_setting( 'reset_theme_options', array(
			'sanitize_callback' => 'absint',
		) );
		// control
		$wp_customize->add_control( new Collect_Reset_Control(
			$wp_customize, 'reset_theme_options', array(
				'section' => 'abc_reset',
				'priority' => 1,
				'description' => __( 'Click on the button below to reset all theme options back to default.', 'collect' ),
			)
		) );

		// Don't display upgrade message if ABC Premium Features plugin is activated
		if ( ! function_exists( 'abc_premium_features' ) ) {
			$wp_customize->register_section_type( 'Collect_Customize_Section_Pro' );
			$wp_customize->add_section(
				new Collect_Customize_Section_Pro ( $wp_customize, 'premium_upgrade', array(
					'title'    => esc_html__( 'Unlock Premium Theme Options', 'collect' ),
					'pro_url'  => 'https://alphabetthemes.com/downloads/abc-premium-features/',
					'priority' => 999,
				) )
			);
		}
	}

	public function customize_preview_init() {
		wp_enqueue_script( 'collect-customizer', COLLECT_THEME_URL . '/js/admin/customizer.js', array( 'customize-preview' ), '', true );
	}

	public function customize_controls_enqueue_scripts() {
		wp_enqueue_script( 'collect-customizer-display', COLLECT_THEME_URL . '/js/admin/customizer-display.js', array( 'jquery' ), '', true );
        wp_localize_script( 'collect-customizer-display', 'Collect_Customizer', array(
            'customizerURL' => admin_url( 'customize.php' ),
            'exportNonce' => wp_create_nonce( 'abc-customizer' ),
            'confirmText' => __( 'Are you sure?', 'collect' ),
        ));

		// Don't display upgrade message if ABC Premium Features plugin is activated
		if ( ! function_exists( 'abc_premium_features' ) ) {
			wp_enqueue_script( 'collect-customize-controls', COLLECT_THEME_URL . '/js/admin/upgrade.js', array( 'customize-controls' ) );
		}

		wp_enqueue_style( 'collect-customizer-styles', COLLECT_THEME_URL . '/css/admin/customizer.css' );
	}
}
$collect_customizer = new Collect_Customizer;

function collect_sanitize_checkbox( $checked ) {
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

function collect_sanitize_text( $input ) {
	return wp_kses_post( force_balance_tags( $input ) );
}